@@ -53,9 +53,9 @@ finally:
                         print(self.dst)
                         try:
                             Put(f, self.dst).put()
-                            utils.send_email(f'{f.__class__.__name__} Transfer Found', f.__str__())
+                            send_email(f'{f.__class__.__name__} Transfer Found', f.__str__())
                         except Exception as e:
-                            utils.send_email(f'{f.__class__.__name__} Transfer Found', f'AN ERROR OCCURED: {e} ')
+                            send_email(f'{f.__class__.__name__} Transfer Found', f'AN ERROR OCCURED: {e} ')
                             print(e)
 
         def run(self):
