@@ -1,4 +1,5 @@
-from . import Path, File
+from .path import Path
+from .files import File
 
 __all__ = ['Snapshot']
 
